OC.L10N.register(
    "settings",
    {
    "Wrong password" : "密碼錯誤",
    "No user supplied" : "未提供使用者",
    "Authentication error" : "認證錯誤",
    "Wrong admin recovery password. Please check the password and try again." : "錯誤的管理者還原密碼",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "後端不支援變更密碼，但成功更新使用者的加密金鑰",
    "Unable to change password" : "無法修改密碼",
    "Couldn't send reset email. Please contact your administrator." : "無法寄送重設 email ，請聯絡系統管理員",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "透過應用程式中心或是聯盟式雲端分享來安裝、更新應用程式",
    "Federated Cloud Sharing" : "聯盟式雲端分享",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL 使用的 %s 版本已經過期 (%s)，請您更新您的作業系統，否則功能如 %s 可能無法正常運作",
    "A problem occurred, please check your log files (Error: %s)" : "出現問題，請您檢查您的記錄檔（錯誤：%s）",
    "Migration Completed" : "遷移已完成",
    "Group already exists." : "群組已存在",
    "Unable to add group." : "無法新增群組",
    "Unable to delete group." : "無法刪除群組",
    "log-level out of allowed range" : "log-level 超過允許範圍",
    "Saved" : "已儲存",
    "test email settings" : "測試郵件設定",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "寄出郵件時發生問題，請檢查您的設定（錯誤訊息：%s）",
    "Email sent" : "Email 已寄出",
    "You need to set your user email before being able to send test emails." : "在寄出測試郵件前您需要設定信箱位址",
    "Invalid mail address" : "無效的 email 地址",
    "A user with that name already exists." : "同名的使用者已經存在",
    "Unable to create user." : "無法建立使用者",
    "Your %s account was created" : "您的 %s 帳號已經建立",
    "Unable to delete user." : "無法移除使用者",
    "Forbidden" : "存取被拒",
    "Invalid user" : "無效的使用者",
    "Unable to change mail address" : "無法更改 email 地址",
    "Your full name has been changed." : "您的全名已變更",
    "Unable to change full name" : "無法變更全名",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "__language_name__",
    "Language changed" : "語言已變更",
    "Invalid request" : "無效請求",
    "Admins can't remove themself from the admin group" : "管理者帳號無法從管理者群組中移除",
    "Unknown user" : "未知的使用者",
    "Couldn't remove app." : "無法移除應用程式",
    "Official" : "官方",
    "Approved" : "審查通過",
    "All" : "所有",
    "Enabled" : "已啓用",
    "Not enabled" : "未啟用",
    "No apps found for your version" : "沒有找到適合您的版本的應用程式",
    "The app will be downloaded from the app store" : "將會從應用程式商店下載應用程式",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "官方應用程式由 ownCloud 社群開發，他們提供 ownCloud 的主要功能，並確保穩定性足供正式使用",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "審查通過的應用程式經由可信任的開發人員所設計，並且經過一連串的安全測試，他們在開放的程式庫中維護這些應用程式，而且確保這些應用程式能穩定運作",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "這個新應用程式並沒有經過安全檢測，可能會是不穩定的，如果您要安裝的話，風險自行負責。",
    "Please wait...." : "請稍候…",
    "Error while disabling app" : "停用應用程式錯誤",
    "Disable" : "停用",
    "Enable" : "啟用",
    "Error while enabling app" : "啟用應用程式錯誤",
    "Error: this app cannot be enabled because it makes the server unstable" : "錯誤：無法啟用此應用程式，因為將會導致伺服器不穩定",
    "Error: could not disable broken app" : "錯誤：無法停用這個有問題的應用程式",
    "Error while disabling broken app" : "停用有問題的應用程式的時候出錯",
    "Updating...." : "更新中…",
    "Error while updating app" : "更新應用程式錯誤",
    "Updated" : "已更新",
    "Uninstalling ...." : "正在解除安裝…",
    "Error while uninstalling app" : "移除應用程式錯誤",
    "Uninstall" : "解除安裝",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "這個應用程式已啟用但是需要更新，您將會在 5 秒後被引導至更新頁面",
    "App update" : "應用程式更新",
    "Experimental" : "實驗性質",
    "No apps found for {query}" : "沒有應用程式符合 {query}",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "您確定要新增 \"{domain}\" 為信任的網域？",
    "Add trusted domain" : "新增信任的網域",
    "Migration in progress. Please wait until the migration is finished" : "資料搬移中，請耐心等候直到資料搬移結束",
    "Migration started …" : "開始遷移…",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "發生錯誤，請您上傳 ASCII 編碼的 PEM 憑證",
    "Valid until {date}" : "{date} 前有效",
    "Delete" : "刪除",
    "Disconnect" : "中斷連線",
    "Error while loading browser sessions and device tokens" : "載入瀏覽器工作階段和裝置 token 時發生錯誤",
    "Sending..." : "傳送中…",
    "An error occurred: {message}" : "發生錯誤：{message}",
    "Select a profile picture" : "選擇大頭貼",
    "Very weak password" : "密碼強度非常弱",
    "Weak password" : "密碼強度弱",
    "So-so password" : "密碼強度普通",
    "Good password" : "密碼強度佳",
    "Strong password" : "密碼強度極佳",
    "Groups" : "群組",
    "Unable to delete {objName}" : "無法刪除 {objName}",
    "A valid group name must be provided" : "必須提供一個有效的群組名稱",
    "deleted {groupName}" : "刪除 {groupName}",
    "undo" : "復原",
    "never" : "永不",
    "deleted {userName}" : "刪除 {userName}",
    "add group" : "新增群組",
    "enabled" : "啟動的",
    "disabled" : "無效的",
    "no group" : "沒有群組",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "更改密碼會造成資料遺失，因為資料復原的功能無法在這個使用者使用",
    "A valid username must be provided" : "必須提供一個有效的用戶名",
    "A valid password must be provided" : "一定要提供一個有效的密碼",
    "A valid email must be provided" : "必須提供一個有效的電子郵件地址",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "嗨，<br><br>通知您一聲，您現在有了 %s 的帳號。<br><br>您的帳號： %s<br>開通帳號： <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "太棒了！",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "嗨，\n\n通知您一聲，您現在有了 %s 的帳號。\n\n您的帳號：%s\n開通帳號：%s\n\n",
    "User documentation" : "用戶說明文件",
    "Administrator documentation" : "管理者說明文件",
    "Online documentation" : "線上說明文件",
    "Forum" : "論壇",
    "Issue tracker" : "問題追蹤",
    "Commercial support" : "商用支援",
    "Developer documentation" : "開發者說明文件",
    "Documentation:" : "說明文件：",
    "Admin documentation" : "管理者文件",
    "Show description …" : "顯示描述",
    "Hide description …" : "隱藏描述",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "此應用程式沒有指定支援的最小 ownCloud 版本，從 ownCloud 11 之後這會是個錯誤",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "此應用程式沒有指定支援的最大 ownCloud 版本，從 ownCloud 11 之後這會是個錯誤",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "這個應用程式無法被安裝，因為欠缺下列相依套件：",
    "Enable only for specific groups" : "僅對特定的群組啟用",
    "Uninstall App" : "解除安裝 App",
    "Cron" : "工作排程",
    "Last cron job execution: %s." : "最近一次執行的排程工作：%s",
    "Last cron job execution: %s. Something seems wrong." : "最近一次執行的排程工作：%s ，看起來發生了一些錯誤",
    "Cron was not executed yet!" : "Cron 沒有執行！",
    "Open documentation" : "開啟說明文件",
    "Execute one task with each page loaded" : "每個頁面載入時執行",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "已經與 webcron 服務註冊好，將會每 15 分鐘透過 HTTP 呼叫 cron.php",
    "Use system's cron service to call the cron.php file every 15 minutes." : "使用系統的 cron 服務每 15 分鐘呼叫 cron.php 一次",
    "SSL Root Certificates" : "SSL 根憑證",
    "Common Name" : "Common Name",
    "Valid until" : "到期日",
    "Issued By" : "發行者：",
    "Valid until %s" : "有效至 %s",
    "Import root certificate" : "匯入根憑證",
    "Server-side encryption" : "伺服器端加密",
    "Enable server-side encryption" : "啟用伺服器端加密",
    "Please read carefully before activating server-side encryption: " : "在您啟動伺服器端加密之前，請仔細閱讀：",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "一旦加密模式啟動，從各地上傳到伺服器端的檔案都會被加密，若日後要停用加密，需要加密模組的支援，而且所有的設定（例如: 還原金鑰）都正確",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "單純的加密不能保障系統的安全，請參閱 ownCloud 說明文件以瞭解加密程式的運作，還有它支援的使用情境",
    "Be aware that encryption always increases the file size." : "請注意，加密一定會增加檔案的大小",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "定時備份您的資料沒有壞處，若您有啟用加密，請確保您也有備份加密金鑰",
    "This is the final warning: Do you really want to enable encryption?" : "這是最後的警告：請問您真的要開啟加密模式？",
    "Enable encryption" : "啟用加密",
    "No encryption module loaded, please enable an encryption module in the app menu." : "沒有載入加密模組，請您在應用程式清單中啟用加密模組",
    "Select default encryption module:" : "選擇預設的加密模組：",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : " 您需要遷移您的加密金鑰從舊版的加密 (ownCloud <= 8.0) 到新版，請啟用「預設加密模組」並執行 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : " 您需要遷移您的加密金鑰從舊版的加密 (ownCloud <= 8.0) 到新版",
    "Start migration" : "開始遷移",
    "Sharing" : "分享",
    "Allow apps to use the Share API" : "允許 apps 使用分享 API",
    "Allow users to share via link" : "允許使用者透過連結分享",
    "Allow public uploads" : "允許公開上傳",
    "Enforce password protection" : "強制分享連結使用密碼保護",
    "Set default expiration date" : "設定預設到期日",
    "Allow users to send mail notification for shared files" : "允許使用者寄送有關分享檔案的郵件通知",
    "Expire after " : "在什麼時候過期",
    "days" : "天",
    "Enforce expiration date" : "強制分享連結設定到期日",
    "Allow resharing" : "允許轉分享",
    "Allow sharing with groups" : "允許和群組分享",
    "Restrict users to only share with users in their groups" : "限制使用者只能分享給群組裡的其他使用者",
    "Allow users to send mail notification for shared files to other users" : "允許使用者寄送檔案分享通知給其他使用者",
    "Exclude groups from sharing" : "禁止特定群組分享檔案",
    "These groups will still be able to receive shares, but not to initiate them." : "這些群組仍然能接受其他人的分享，但是沒有辦法發起分享",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "允許使用者名稱自動補齊在分享對話框，如果取消這個功能，必須完整輸入使用者名稱",
    "Everything (fatal issues, errors, warnings, info, debug)" : "全部（嚴重問題、錯誤、警告、資訊、除錯訊息）",
    "Info, warnings, errors and fatal issues" : "嚴重問題、錯誤、警告、資訊",
    "Warnings, errors and fatal issues" : "嚴重問題、錯誤、警告",
    "Errors and fatal issues" : "錯誤和嚴重問題",
    "Fatal issues only" : "只有嚴重問題",
    "Log" : "紀錄檔",
    "What to log" : "記錄哪些訊息",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "記錄檔大於 100MB，下載可能需要一些時間！",
    "None" : "無",
    "Login" : "登入",
    "Plain" : "Plain",
    "NT LAN Manager" : "NT LAN Manager",
    "Email server" : "郵件伺服器",
    "This is used for sending out notifications." : "用於寄送通知",
    "Send mode" : "寄送模式",
    "Encryption" : "加密",
    "From address" : "寄件地址",
    "mail" : "電子郵件",
    "Authentication method" : "認證方式",
    "Authentication required" : "需要認證",
    "Server address" : "伺服器位址",
    "Port" : "連接埠",
    "Credentials" : "帳密",
    "SMTP Username" : "SMTP 帳號",
    "SMTP Password" : "SMTP 密碼",
    "Store credentials" : "儲存帳密",
    "Test email settings" : "測試郵件設定",
    "Send email" : "寄送郵件",
    "Security & setup warnings" : "安全及設定警告",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP 看起來沒有設定完成，無法正確取得系統環境變數，getenv(\"PATH\") 回傳資料為空值",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "請您參考 <a target=\\\"_blank\\\" href=\\\"%s\\\">安裝文件手冊 ↗</a> 來確認php的設定值以及伺服器端的php設定，特別是當您使用php-fpm。",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "「唯讀設定檔」已經啟用，這樣可以防止來自網頁端的設定操作，每次需要更改設定時，都需要手動將設定檔暫時改為可讀寫。",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP 已經設定成「剪除 inline doc block」模式，這將會使幾個核心應用程式無法使用",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "這大概是由快取或是加速器像是 Zend OPcache, eAccelerator 造成的",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "未偵測到 PHP 模組 'fileinfo'。我們強烈建議啟用這個模組以取得最好的 mime-type 支援。",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "事務型文件鎖定的功能已經取消，這可能會造成競態條件，請在 config.php 中啟用 'filelocking.enabled' 以避免出現這樣的問題，請參考<a target=\\\"_blank\\\" href=\\\"%s\\\">文件手冊 ↗</a> 來了解更多的資訊。",
    "System locale can not be set to a one which supports UTF-8." : "無法設定為一個支援 UTF-8 的系統語系",
    "This means that there might be problems with certain characters in file names." : "這表示檔名中使用一些特殊字元可能會造成問題",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "我們強烈建議在您的系統上安裝必要的套件來支援以下的語系：%s",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "如果您的安裝不在網域的最上層，並且使用 cron 作為排程器，URL 的生成可能會有問題，為了避免這樣的狀況，請您在 config.php 檔案裡設定 overwrite.cli.url 為您安裝的 webroot 路徑（建議值：\"%s\"）",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "將會使用 SQLite 作為資料庫，在大型安裝中建議使用其他種資料庫",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "若使用桌面版程式同步檔案，不建議使用 SQLite",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : " 無法透過 CLI 來執行排程工作，發生以下技術性錯誤：",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "請再次檢查 <a target=\"_blank\" href=\"%s\">安裝手冊 ↗</a>，並且確定沒有任何的錯誤或是警告訊息在 <a href=\"#log-section\">記錄檔</a>",
    "All checks passed." : "所有檢查正常",
    "Tips & tricks" : "技巧和提示",
    "How to do backups" : "如何備份",
    "Advanced monitoring" : "進階監控",
    "Performance tuning" : "效能調校",
    "Improving the config.php" : "改進 config.php",
    "Theming" : "佈景主題",
    "Hardening and security guidance" : "增強安全性",
    "Get the apps to sync your files" : "下載應用程式來同步您的檔案",
    "Desktop client" : "桌面客戶端",
    "Android app" : "Android 應用程式",
    "iOS app" : "iOS 應用程式",
    "Show First Run Wizard again" : "再次顯示首次使用精靈",
    "Profile picture" : "大頭照",
    "Upload new" : "上傳新的",
    "Select from Files" : "從檔案應用程式選擇",
    "Remove image" : "移除圖片",
    "png or jpg, max. 20 MB" : "png 或 jpg ，最大 20 MB",
    "Picture provided by original account" : "原本的帳戶提供的圖片",
    "Cancel" : "取消",
    "Choose as profile picture" : "選為大頭照",
    "Full name" : "全名",
    "No display name set" : "未設定顯示名稱",
    "Email" : "信箱",
    "Your email address" : "您的電子郵件信箱",
    "For password recovery and notifications" : "用於密碼重設和通知",
    "No email address set" : "未設定電子郵件信箱",
    "You are member of the following groups:" : "您的帳號屬於這些群組：",
    "Password" : "密碼",
    "Unable to change your password" : "無法變更您的密碼",
    "Current password" : "目前密碼",
    "New password" : "新密碼",
    "Change password" : "變更密碼",
    "Language" : "語言",
    "Help translate" : "幫助翻譯",
    "Unlimited" : "無限制",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "由 {communityopen}ownCloud 社群{linkclose} 開發，{githubopen}原始碼{linkclose}使用 {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose} 授權釋出",
    "Name" : "名稱",
    "Username" : "使用者名稱",
    "Done" : "完成",
    "Version" : "版本",
    "Personal" : "個人",
    "Admin" : "管理",
    "Error" : "錯誤",
    "Show storage location" : "顯示儲存位置",
    "Show last log in" : "顯示最近登入",
    "Show user backend" : "顯示用戶後台",
    "Send email to new user" : "寄送郵件給新用戶",
    "Show email address" : "顯示電子郵件信箱",
    "E-Mail" : "電子郵件",
    "Create" : "建立",
    "Admin Recovery Password" : "管理者復原密碼",
    "Enter the recovery password in order to recover the users files during password change" : "為了修改密碼時能夠取回使用者資料，請輸入另一組還原用密碼",
    "Add Group" : "新增群組",
    "Group" : "群組",
    "Everyone" : "所有人",
    "Admins" : "管理者",
    "Default Quota" : "預設容量限制",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "請輸入空間配額（例如 \"512 MB\" 或是 \"12 GB\"）",
    "Other" : "其他",
    "Full Name" : "全名",
    "Group Admin for" : "指定群組管理者",
    "Quota" : "容量限制",
    "Storage Location" : "儲存位置",
    "User Backend" : "用戶後端",
    "Last Login" : "上次登入",
    "change full name" : "變更全名",
    "set new password" : "設定新密碼",
    "change email address" : "更改電子郵件地址",
    "Default" : "預設",
    "Share" : "分享",
    "Domain" : "網域名稱",
    "Add" : "增加",
    "Email has been changed successfully." : "電子郵件已經成功變更",
    "%s password changed successfully" : "%s 密碼修改成功"
},
"nplurals=1; plural=0;");
